/*
             LUFA Library
     Copyright (C) Dean Camera, 2021.

  dean [at] fourwalledcubicle [dot] com
           www.lufa-lib.org
*/

/*
  Copyright 2021  Dean Camera (dean [at] fourwalledcubicle [dot] com)

  Permission to use, copy, modify, distribute, and sell this
  software and its documentation for any purpose is hereby granted
  without fee, provided that the above copyright notice appear in
  all copies and that both that the copyright notice and this
  permission notice and warranty disclaimer appear in supporting
  documentation, and that the name of the author not be used in
  advertising or publicity pertaining to distribution of the
  software without specific, written prior permission.

  The author disclaims all warranties with regard to this
  software, including all implied warranties of merchantability
  and fitness.  In no event shall the author be liable for any
  special, indirect or consequential damages or any damages
  whatsoever resulting from loss of use, data or profits, whether
  in an action of contract, negligence or other tortious action,
  arising out of or in connection with the use or performance of
  this software.
*/

/** \file
 *
 *  Header file for usbcas.c (USB serial to ABC cassette)
 */

#ifndef _USB_CAS_H_
#define _USB_CAS_H_

/* Includes: */
#include <avr/io.h>
#include <avr/wdt.h>
#include <avr/interrupt.h>
#include <avr/power.h>

#include "Descriptors.h"

#include <LUFA/Drivers/Peripheral/SerialSPI.h>
#include <LUFA/Drivers/Misc/RingBuffer.h>
#include <LUFA/Drivers/USB/USB.h>
#include <LUFA/Platform/Platform.h>


/* Function Prototypes: */
void SetupHardware(void);
void do_usb_tasks(void);

void EVENT_USB_Device_Connect(void);
void EVENT_USB_Device_Disconnect(void);
void EVENT_USB_Device_ConfigurationChanged(void);
void EVENT_USB_Device_ControlRequest(void);

void EVENT_CDC_Device_LineEncodingChanged(USB_ClassInfo_CDC_Device_t* const CDCInterfaceInfo);
void EVENT_CDC_Device_ControLineStateChanged(USB_ClassInfo_CDC_Device_t* const CDCInterfaceInfo);

int fmtx_next_byte(void);
void fmtx_drain(void);
uint32_t fmtx_real_baudrate(uint32_t baudrate);
void fmtx_init_speed(uint32_t baudrate);
/* Enable the TX ISR which enables sending data */
static inline ATTR_ALWAYS_INLINE void fmtx_enable(void)
{
	UCSR1B |= (1 << UDRIE1);
	PORTB &= ~(1 << 0);
}
extern bool _motor_relay;

static inline ATTR_ALWAYS_INLINE bool motor_relay(void)
{
	return _motor_relay;
}

void fmrx_init(void);
void fmrx_set_speed(uint32_t baudrate);
void fmrx_recv_byte(uint8_t byte);

/* Parameters */
#define CAS_BAUDRATE_ABC80	725
#define CAS_BAUDRATE_ABC800	2680

#endif
